@@ -12,11 +12,6 @@ class BaseParticle():
     Base class for Wulff constructions, useful for systems of
     (almost) any symmetry.
 
-    The Wulff construction calculates the vertices of the dual,
-    calculates the convex hull of those vertices using scipy's
-    ConvexHull, and then converts the dual back to the Wulff
-    shape.
-
     Parameters
     ----------
     forms
@@ -51,23 +46,13 @@ class BaseParticle():
         self._standardized_structure = standardized_structure
         self._forms = forms
         self.tol = tol
+        self._SMALL = 1e-12
 
-        # Calculate convex hull of dual vertices
-        duals = []
-        facets = [facet for facet in self._yield_facets()]
-        for facet in self._yield_facets():
-            facet_points = facet.normal * facet.energy
-            duals.append(facet_points / np.dot(facet_points, facet_points))
-        hull = ConvexHull(duals)
-
-        # Calculate vertices of dual again (i.e., back to Wulff shape)
-        for i, j, k in hull.simplices:
-            normal = np.cross(duals[j] - duals[i], duals[k] - duals[i])
-            if np.linalg.norm(normal) < 1e-12:
-                continue # Rare instances of duals on a line
-            normal *= facets[i].energy / np.dot(normal, facets[i].normal)
-            for facet_i in (i, j, k):
-                facets[facet_i].add_vertex(normal.copy())
+        facets = list(self._yield_facets())
+        if min(f.energy for f in facets) < 0:  # interface energy can be negative
+            self._closest_vertices(facets)
+        else:
+            self._dual_wulff_shape(facets)
 
         # Remove vertices that are on the line between two other vertices
         # (relevant in the Winterbottom case and some corner cases)
@@ -88,6 +73,103 @@ class BaseParticle():
         scale_factor = (target_volume / (ngrains * self.volume * volume_scale)) ** (1 / 3)
         self._scale_size(scale_factor)
 
+    def __str__(self) -> str:
+        width = 38
+        s = []
+        name = self.__class__.__name__
+        s += ['{s:-^{n}}'.format(s=f' {name} ', n=width)]
+        flds = dict(volume='12.4f', area='12.4f',
+                    surface_energy='12.2f', average_surface_energy='12.4f',
+                    edge_length='12.4f', number_of_corners='12d')
+        for fld, fmt in flds.items():
+            s += ['{fld:22} : {value:{fmt}}'.format(fld=fld, value=getattr(self, fld), fmt=fmt)]
+        s += ['facet_fractions        :']
+        for k, v in self.facet_fractions.items():
+            s += [f'  {str(k):20} : {v:12.6f}']
+        return '\n'.join(s)
+
+    def _repr_html_(self) -> str:
+        s = []
+        s += ['<table border="1" class="dataframe"']
+        s += [
+            '<thead><tr><th style="text-align: left;">Property</th><th>Value</th></tr></thead>'
+        ]
+        s += ['<tbody>']
+        flds = dict(volume='12.4f', area='12.4f',
+                    surface_energy='12.2f', average_surface_energy='12.4f',
+                    edge_length='12.4f', number_of_corners='12d')
+        for fld, fmt in flds.items():
+            s += [
+                f'<tr><td style="text-align: left">{fld:22}</td>'
+                '<td>{value:{fmt}}</td><tr>'.format(value=getattr(self, fld), fmt=fmt)
+            ]
+        s += '<tr><td style="text-align: left">facet_fractions</td><tr>'
+        for k, v in self.facet_fractions.items():
+            s += [
+                '<tr><td style="text-align: right">'
+                f'{str(k):22}</td><td>{v:.6f}</td><tr>'
+            ]
+        s += ['</tbody>']
+        s += ['</table>']
+        return ''.join(s)
+
+    def _closest_vertices(self, facets):
+        """
+        The closest vertex technique calculates all possible vertices and eliminates
+        vertices outside of the Wulff shape.
+        This works for negative interface energies.
+        """
+        # Calculate intersection point for all possible combinations of three facets
+        facets.sort(key=lambda x: x.energy)  # compare with small energies first in inner loop
+        for i, fi in enumerate(facets):
+            ni = fi.normal
+            for j, fj in enumerate(facets[:i]):
+                nj = fj.normal
+                if abs(abs(np.dot(ni, nj)) - 1) < self._SMALL:
+                    continue  # skip parallel facets
+                for fk in facets[:j]:
+                    mat = np.vstack([ni, nj, fk.normal])
+                    if np.linalg.det(mat) == 0:
+                        continue  # skip singular matrices
+                    vertex = np.dot(np.linalg.inv(mat), [fi.energy, fj.energy, fk.energy])
+
+                    # check if vertex lies outside of Wulff shape
+                    for fl in facets:
+                        projection = np.dot(vertex, fl.normal)
+                        if projection > fl.energy + self._SMALL:
+                            break
+                    else:  # i.e. loop does not break
+                        for f in [fi, fj, fk]:
+                            f.add_vertex(vertex.copy())
+
+    def _dual_wulff_shape(self, facets):
+        """
+        The Wulff construction calculates the vertices of the dual,
+        calculates the convex hull of those vertices using scipy's
+        ConvexHull, and then converts the dual back to the Wulff
+        shape.
+        """
+        # Calculate convex hull of dual vertices
+        duals = []
+        for facet in self._yield_facets():
+            facet_points = facet.normal * facet.energy
+            duals.append(facet_points / np.dot(facet_points, facet_points))
+        hull = ConvexHull(duals)
+
+        # Calculate vertices of dual again (i.e., back to Wulff shape)
+        for i, j, k in hull.simplices:
+            normal = np.cross(duals[j] - duals[i], duals[k] - duals[i])
+            if np.linalg.norm(normal) < self._SMALL:
+                continue  # Rare instances of duals on a line
+            if np.isclose(np.dot(normal, facets[i].normal), 0):
+                raise ValueError('The vertex after the calculation of the dual and the'
+                                 ' original facet are orthogonal. This indicates that the'
+                                 ' facets that are provided cannot form a closed shape.'
+                                 ' Please review your input.')
+            normal *= facets[i].energy / np.dot(normal, facets[i].normal)
+            for facet_i in (i, j, k):
+                facets[facet_i].add_vertex(normal.copy())
+
     def _scale_size(self, scale_factor: float):
         """
         Scale the size of the particle.
@@ -200,7 +282,7 @@ class BaseParticle():
             colors[form.parent_miller_indices] = color
         return colors
 
-    def make_plot(self, ax, alpha: float=0.85, linewidth: float=0.3, colors=None):
+    def make_plot(self, ax, alpha: float = 0.85, linewidth: float = 0.3, colors: dict = None):
         """
         Plot a particle in an axis object. This function can be used to
         make customized plots of particles.
@@ -225,28 +307,28 @@ class BaseParticle():
             >>> from wulffpack import SingleCrystal, Decahedron, Icosahedron
             >>> import matplotlib.pyplot as plt
             >>> from mpl_toolkits.mplot3d import Axes3D
-            >>> 
+            >>>
             >>> surface_energies = {(1, 1, 1): 1.0,
             ...                     (1, 0, 0): 1.1,
             ...                     (1, 1, 0): 1.15,
             ...                     (3, 2, 1): 1.15}
             >>> twin_energy = 0.05
-            >>> 
+            >>>
             >>> fig = plt.figure(figsize=(3*4.0, 4.0))
             >>> ax = fig.add_subplot(131, projection='3d')
             >>> particle = SingleCrystal(surface_energies)
             >>> particle.make_plot(ax)
-            >>> 
+            >>>
             >>> ax = fig.add_subplot(132, projection='3d')
             >>> particle = Decahedron(surface_energies,
             ...                       twin_energy=0.05)
             >>> particle.make_plot(ax)
-            >>> 
+            >>>
             >>> ax = fig.add_subplot(133, projection='3d')
             >>> particle = Icosahedron(surface_energies,
             ...                        twin_energy=0.05)
             >>> particle.make_plot(ax)
-            >>> 
+            >>>
             >>> plt.subplots_adjust(top=1, bottom=0, left=0,
             ...                     right=1, wspace=0, hspace=0)
             >>> plt.savefig('particles.png')
@@ -354,8 +436,8 @@ class BaseParticle():
             # set_box_aspect only available in recent versions of matplotlib
             pass
 
-    def view(self, alpha: float=0.85, linewidth: float=0.3, colors: dict=None,
-             legend: bool=True, save_as: str = None):
+    def view(self, alpha: float = 0.85, linewidth: float = 0.3, colors: dict = None,
+             legend: bool = True, save_as: str = None):
         """
         Use matplotlib to view a rendition of the particle.
 
@@ -424,7 +506,7 @@ class BaseParticle():
                         vertex_counter += len(facet.vertices)
                         f.write('f ' + ' '.join(s) + '\n')
 
-    def _yield_facets(self, only_original_grains=False) -> Facet:
+    def _yield_facets(self, only_original_grains: bool = False) -> Facet:
         """Generate all facets that are included in the facets dictionary."""
         for form in self.forms:
             for facet in form.facets:
@@ -484,6 +566,12 @@ class BaseParticle():
             E += form.surface_energy
         return E
 
+    @property
+    def facets(self) -> List[Facet]:
+        """The facets of the particle (read-only).
+        """
+        return list(self._yield_facets())
+
     @property
     def facet_fractions(self) -> Dict[tuple, float]:
         """
@@ -582,7 +670,7 @@ class BaseParticle():
         for atom in self.standardized_structure:
             atom.position = np.dot(rotation, atom.position)
 
-    def _get_atoms(self, center_shift: Tuple[float, float, float]=None) -> Atoms:
+    def _get_atoms(self, center_shift: Tuple[float, float, float] = None) -> Atoms:
         """
         Returns an ASE Atoms object the atoms of which are all
         within the facets. In polycrystalline particles, only
